@@ -90,8 +90,8 @@ class TflAppMain(QtGui.QMainWindow):
             self.progress.setLabelText("Geolocating postcode")
             pCode = self.getCurrentPCodeFromLoc()
         else:
-            # set the current location to be somewhere in London. COnfusing? Yes, but helpful in testing :)
-            os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Does not work outside London - Blame tfl :)"')
+            infoText = "Sorry, but it appears that you're outside London. The tfl Journeyplanner only works when you're within London :("
+            QtGui.QMessageBox.information(self, "Whoops", infoText)
             pCode = ""
         
         return pCode
@@ -129,6 +129,7 @@ class TflAppMain(QtGui.QMainWindow):
         self.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator )
         self.tubemap.setupWindow()
         self.tubemap.show()
+        self.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator, False )
         return
 
     #Note that this is only ever triggered if the user hits "return" ont eh keyboard
@@ -190,5 +191,5 @@ if __name__ == "__main__":
     
     tflapp = TflAppMain()
     tflapp.show()
-    
+    #hildon.hildon_gtk_window_take_screenshot(tflapp.ui, True)
     sys.exit(app.exec_())
