@@ -20,5 +20,5 @@ class TubeMapDisplay(QtGui.QMainWindow):
         self.scrollArea.setWidget(self.pic)
         self.scrollArea.setGeometry(QtCore.QRect(0, 0, 800, 424))
         self.scrollArea.setWidgetResizable(True)
-        parent = self.nativeParentWidget()
-        parent.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator, False )
+        self.scrollArea.ensureVisible(668,480)
+
